# ZOOM API

Provides functionality for developers that would like to interact the Zoom API. This modules tries to make little assumptions about how you would like to interact with the API and focuses and ease of connection.

Note: Currently this module ONLY supports JWT to interact with the API. See the JWT section at https://marketplace.zoom.us/docs/api-reference/using-zoom-apis

## Installation
Since the module requires an external library, Composer must be used.

### Composer
If your site is [managed via Composer](https://www.drupal.org/node/2718229), use Composer to
download the module, which will also download the required library:
   ```sh
   composer require "drupal/zoomapi ~1.0"
   ```
~1.0 downloads the latest release, use 1.x-dev to get the -dev release instead.
Use ```composer update drupal/zoomapi --with-dependencies``` to update to a new release.


### Enable ZoomAPI

Enable like any Drupal module. https://www.drupal.org/docs/8/extending-drupal-8/installing-drupal-8-modules

## Usage

### Configuration
1. Create a Zoom Application https://marketplace.zoom.us/develop/create (JWT)
2. After enabling the module set the necessary configuration at /admin/config/zoomapi
3. If using webhooks, enable them in your Zoom Application. Add the Webhook Verification Token config.

### Webhooks
You'll need to add an additonal Webhook Verification Token in the configuration at /admin/config/zoomapi
Configure your Zoom Application to send webhooks to https://example.com/zoomapi-webhooks
All webhooks dispatch an event that can be subscribed to.

1. In your custom module, add the following to your_module.services.yml

```
services:
  your_module.event_subscriber:
    class: Drupal\your_module\ZoomApiWebhookEventSubscriber
    tags:
      - {name: event_subscriber}
```

2. In your custom module (custom_module/src) add ZoomApiWebhookEventSubscriber.php

```
<?php

namespace Drupal\your_module;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\zoomapi\Event\ZoomApiEvents;
use Drupal\zoomapi\Event\ZoomApiWebhookEvent;

/**
 * Class ZoomApiWebhookEventSubscriber.
 *
 * @package Drupal\your_module\ZoomApiWebhookEventSubscriber
 */
class ZoomApiWebhookEventSubscriber implements EventSubscriberInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ZoomApiEvents::WEBHOOK_POST][] = ['subscribe'];
    return $events;
  }

  /**
   * {@inheritdoc}
   */
  public function subscribe(ZoomApiWebhookEvent $event) {
    \Drupal::logger('your_module')->debug($event->getEvent());
  }

}
```

### API Client

1. Inject or statically call the Zoom API Client in your code.

`$client = Drupal::service('zoomapi.client');`
The client is based on Drupal HttpClient.

See zoomapi/src/ZoomApiClientInterface.php for var definitions.
`$response = $client->request($method, $endpoint, $query, $body);`

If successful, an array of decoded JSON will be returned.


## Debugging
All errors are logged to watchdog.
